summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KMdiMainFrm.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KMdiMainFrm.java')
-rw-r--r--kdejava/koala/org/kde/koala/KMdiMainFrm.java112
1 files changed, 56 insertions, 56 deletions
diff --git a/kdejava/koala/org/kde/koala/KMdiMainFrm.java b/kdejava/koala/org/kde/koala/KMdiMainFrm.java
index 5fae8021..240544bc 100644
--- a/kdejava/koala/org/kde/koala/KMdiMainFrm.java
+++ b/kdejava/koala/org/kde/koala/KMdiMainFrm.java
@@ -2,24 +2,24 @@
package org.kde.koala;
import org.kde.qt.Qt;
-import org.kde.qt.QColor;
-import org.kde.qt.QRect;
-import org.kde.qt.QMetaObject;
+import org.kde.qt.TQColor;
+import org.kde.qt.TQRect;
+import org.kde.qt.TQMetaObject;
import org.kde.qt.QtSupport;
-import org.kde.qt.QObject;
-import org.kde.qt.QPopupMenu;
-import org.kde.qt.QPixmap;
-import org.kde.qt.QPoint;
-import org.kde.qt.QSize;
+import org.kde.qt.TQObject;
+import org.kde.qt.TQPopupMenu;
+import org.kde.qt.TQPixmap;
+import org.kde.qt.TQPoint;
+import org.kde.qt.TQSize;
import java.util.ArrayList;
-import org.kde.qt.QEvent;
-import org.kde.qt.QWidget;
-import org.kde.qt.QResizeEvent;
+import org.kde.qt.TQEvent;
+import org.kde.qt.TQWidget;
+import org.kde.qt.TQResizeEvent;
/**
\short Base class for all your special main frames.
- It contains the child frame area (QMainWindow's central widget) and a child view taskbar
+ It contains the child frame area (TQMainWindow's central widget) and a child view taskbar
for switching the MDI views. Most methods are functions for later overriding.
Basically, this class provides functionality for docking/undocking view windows and
manages the taskbar. Usually a developer will only need to know about this class and
@@ -55,7 +55,7 @@ import org.kde.qt.QResizeEvent;
setMenuForSDIModeSysButtons( menuBar() );
}
...
- void B_MainModuleWidget.resizeEvent ( QResizeEvent e )
+ void B_MainModuleWidget.resizeEvent ( TQResizeEvent e )
{
KMdiMainFrm.resizeEvent( e );
setSysButtonsAtMenuPosition();
@@ -142,7 +142,7 @@ import org.kde.qt.QResizeEvent;
}
else
{
- m_pMdiMainFrm.addWindow( pWnd, QPoint(20, 20), KMdi.AddWindowFlags(mdiFlags));
+ m_pMdiMainFrm.addWindow( pWnd, TQPoint(20, 20), KMdi.AddWindowFlags(mdiFlags));
return;
}
m_pMdiMainFrm.addWindow( pWnd, KMdi.AddWindowFlags(mdiFlags));
@@ -157,28 +157,28 @@ public class KMdiMainFrm extends DockMainWindow {
public static final int ToolView = 1;
public static final int AnyView = 2;
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
- public KMdiMainFrm(QWidget parentWidget, String name, int mdiMode, int flags) {
+ public KMdiMainFrm(TQWidget parentWidget, String name, int mdiMode, int flags) {
super((Class) null);
newKMdiMainFrm(parentWidget,name,mdiMode,flags);
}
- private native void newKMdiMainFrm(QWidget parentWidget, String name, int mdiMode, int flags);
- public KMdiMainFrm(QWidget parentWidget, String name, int mdiMode) {
+ private native void newKMdiMainFrm(TQWidget parentWidget, String name, int mdiMode, int flags);
+ public KMdiMainFrm(TQWidget parentWidget, String name, int mdiMode) {
super((Class) null);
newKMdiMainFrm(parentWidget,name,mdiMode);
}
- private native void newKMdiMainFrm(QWidget parentWidget, String name, int mdiMode);
- public KMdiMainFrm(QWidget parentWidget, String name) {
+ private native void newKMdiMainFrm(TQWidget parentWidget, String name, int mdiMode);
+ public KMdiMainFrm(TQWidget parentWidget, String name) {
super((Class) null);
newKMdiMainFrm(parentWidget,name);
}
- private native void newKMdiMainFrm(QWidget parentWidget, String name);
- public KMdiMainFrm(QWidget parentWidget) {
+ private native void newKMdiMainFrm(TQWidget parentWidget, String name);
+ public KMdiMainFrm(TQWidget parentWidget) {
super((Class) null);
newKMdiMainFrm(parentWidget);
}
- private native void newKMdiMainFrm(QWidget parentWidget);
+ private native void newKMdiMainFrm(TQWidget parentWidget);
/**
Control whether or not the standard MDI menu is displayed
when a context menu is displayed
@@ -210,15 +210,15 @@ public class KMdiMainFrm extends DockMainWindow {
menu called Operations.
@short Returns a popup menu filled according to the MDI view state.
*/
- public native QPopupMenu taskBarPopup(KMdiChildView pWnd, boolean bIncludeWindowPopup);
- public native QPopupMenu taskBarPopup(KMdiChildView pWnd);
+ public native TQPopupMenu taskBarPopup(KMdiChildView pWnd, boolean bIncludeWindowPopup);
+ public native TQPopupMenu taskBarPopup(KMdiChildView pWnd);
/**
Returns a popup menu with only a title "Window". You can fill it with own operations entries
on the MDI view. This popup menu is inserted as last menu item in taskBarPopup() .
@short Returns a popup menu with only a title "Window".
*/
- public native QPopupMenu windowPopup(KMdiChildView pWnd, boolean bIncludeTaskbarPopup);
- public native QPopupMenu windowPopup(KMdiChildView pWnd);
+ public native TQPopupMenu windowPopup(KMdiChildView pWnd, boolean bIncludeTaskbarPopup);
+ public native TQPopupMenu windowPopup(KMdiChildView pWnd);
/**
Called in the constructor (forces a resize of all MDI views)
@short Called in the constructor (forces a resize of all MDI views)
@@ -243,10 +243,10 @@ public class KMdiMainFrm extends DockMainWindow {
You see, a close() is translated to a closeWindow() .
It is necessary that the main frame has to start an MDI view close action because it must
remove the MDI view from MDI control, additionally.
- This method calls QMainWindow.event , additionally.
+ This method calls TQMainWindow.event , additionally.
@short Catches certain Qt events and processes it here.
*/
- public native boolean event(QEvent e);
+ public native boolean event(TQEvent e);
/**
If there's a main menubar given, it will create the 4 maximize mode buttons there (undock, minimize, restore, close).
@short If there's a main menubar given, it will create the 4 maximize mode buttons there (undock, minimize, restore, close).
@@ -262,7 +262,7 @@ public class KMdiMainFrm extends DockMainWindow {
is visually moved on the desktop by this offset.
@short Sets an offset value that is used on detachWindow() .
*/
- public native void setUndockPositioningOffset(QPoint offset);
+ public native void setUndockPositioningOffset(TQPoint offset);
/**
If you don't want to know about the inner structure of the KMdi system, you can use
this iterator to handle with the MDI view list in a more abstract way.
@@ -281,28 +281,28 @@ public class KMdiMainFrm extends DockMainWindow {
Usually, you insert this popup menu in your main menubar as "Window" menu.
@short Returns a popup menu that contains the MDI controlled view list.
*/
- public native QPopupMenu windowMenu();
+ public native TQPopupMenu windowMenu();
/**
Sets a background color for the MDI view area widget.
@short Sets a background color for the MDI view area widget.
*/
- public native void setBackgroundColor(QColor c);
+ public native void setBackgroundColor(TQColor c);
/**
Sets a background pixmap for the MDI view area widget.
@short Sets a background pixmap for the MDI view area widget.
*/
- public native void setBackgroundPixmap(QPixmap pm);
+ public native void setBackgroundPixmap(TQPixmap pm);
/**
Sets a size that is used as the default size for a newly to the MDI system added KMdiChildView .
By default this size is 600x400. So all non-resized added MDI views appear in that size.
@short Sets a size that is used as the default size for a newly to the MDI system added KMdiChildView .
*/
- public native void setDefaultChildFrmSize(QSize sz);
+ public native void setDefaultChildFrmSize(TQSize sz);
/**
Returns the default size for a newly added KMdiChildView. See setDefaultChildFrmSize() .
@short Returns the default size for a newly added KMdiChildView.
*/
- public native QSize defaultChildFrmSize();
+ public native TQSize defaultChildFrmSize();
/**
Do nothing when in Toplevel mode
@short Do nothing when in Toplevel mode
@@ -314,11 +314,11 @@ public class KMdiMainFrm extends DockMainWindow {
*/
public native int childFrameModeHeight();
/**
- Tells the MDI system a QMenu where it can insert buttons for
+ Tells the MDI system a TQMenu where it can insert buttons for
the system menu, undock, minimize, restore actions.
If no such menu is given, KMdi simply overlays the buttons
at the upper right-hand side of the main widget.
- @short Tells the MDI system a QMenu where it can insert buttons for the system menu, undock, minimize, restore actions.
+ @short Tells the MDI system a TQMenu where it can insert buttons for the system menu, undock, minimize, restore actions.
*/
public native void setMenuForSDIModeSysButtons(KMenuBar menuBar);
public native void setMenuForSDIModeSysButtons();
@@ -345,18 +345,18 @@ public class KMdiMainFrm extends DockMainWindow {
@short
*/
public native boolean isFakingSDIApplication();
- public native boolean eventFilter(QObject arg1, QEvent e);
- // void findRootDockWidgets(QPtrList<KDockWidget>* arg1,QValueList<QRect>* arg2); >>>> NOT CONVERTED
+ public native boolean eventFilter(TQObject arg1, TQEvent e);
+ // void findRootDockWidgets(TQPtrList<KDockWidget>* arg1,TQValueList<TQRect>* arg2); >>>> NOT CONVERTED
/** We're switching something. @short We're switching something.
*/
public native void setSwitching(boolean switching);
public native boolean switching();
/**
- addWindow demands a KMdiChildView. This method wraps every QWidget in such an object and
+ addWindow demands a KMdiChildView. This method wraps every TQWidget in such an object and
this way you can put every widget under MDI control.
@short addWindow demands a KMdiChildView.
*/
- public native KMdiChildView createWrapper(QWidget view, String name, String shortName);
+ public native KMdiChildView createWrapper(TQWidget view, String name, String shortName);
/**
Adds a KMdiChildView to the MDI system. The main frame takes control of it.
\param pWnd the parent view.
@@ -398,8 +398,8 @@ public class KMdiMainFrm extends DockMainWindow {
added as document-type view.
@short Adds a KMdiChildView to the MDI system.
*/
- public native void addWindow(KMdiChildView pWnd, QPoint pos, int flags);
- public native void addWindow(KMdiChildView pWnd, QPoint pos);
+ public native void addWindow(KMdiChildView pWnd, TQPoint pos, int flags);
+ public native void addWindow(KMdiChildView pWnd, TQPoint pos);
/**
Adds a KMdiChildView to the MDI system. The main frame takes control of it.
\param pWnd the parent view.
@@ -412,20 +412,20 @@ public class KMdiMainFrm extends DockMainWindow {
added as document-type view.
@short Adds a KMdiChildView to the MDI system.
*/
- public native void addWindow(KMdiChildView pWnd, QRect rectNormal, int flags);
- public native void addWindow(KMdiChildView pWnd, QRect rectNormal);
+ public native void addWindow(KMdiChildView pWnd, TQRect rectNormal, int flags);
+ public native void addWindow(KMdiChildView pWnd, TQRect rectNormal);
/**
Usually called from addWindow() when adding a tool view window. It reparents the given widget
as toplevel and stay-on-top on the application's main widget.
@short Usually called from addWindow() when adding a tool view window.
*/
- public native KMdiToolViewAccessor addToolWindow(QWidget pWnd, int pos, QWidget pTargetWnd, int percent, String tabToolTip, String tabCaption);
- public native KMdiToolViewAccessor addToolWindow(QWidget pWnd, int pos, QWidget pTargetWnd, int percent, String tabToolTip);
- public native KMdiToolViewAccessor addToolWindow(QWidget pWnd, int pos, QWidget pTargetWnd, int percent);
- public native KMdiToolViewAccessor addToolWindow(QWidget pWnd, int pos, QWidget pTargetWnd);
- public native KMdiToolViewAccessor addToolWindow(QWidget pWnd, int pos);
- public native KMdiToolViewAccessor addToolWindow(QWidget pWnd);
- public native void deleteToolWindow(QWidget pWnd);
+ public native KMdiToolViewAccessor addToolWindow(TQWidget pWnd, int pos, TQWidget pTargetWnd, int percent, String tabToolTip, String tabCaption);
+ public native KMdiToolViewAccessor addToolWindow(TQWidget pWnd, int pos, TQWidget pTargetWnd, int percent, String tabToolTip);
+ public native KMdiToolViewAccessor addToolWindow(TQWidget pWnd, int pos, TQWidget pTargetWnd, int percent);
+ public native KMdiToolViewAccessor addToolWindow(TQWidget pWnd, int pos, TQWidget pTargetWnd);
+ public native KMdiToolViewAccessor addToolWindow(TQWidget pWnd, int pos);
+ public native KMdiToolViewAccessor addToolWindow(TQWidget pWnd);
+ public native void deleteToolWindow(TQWidget pWnd);
public native void deleteToolWindow(KMdiToolViewAccessor accessor);
/**
Using this method you have to use the setWidget method of the access object, and it is very recommendet, that you use
@@ -614,7 +614,7 @@ public class KMdiMainFrm extends DockMainWindow {
@short
*/
public static native int frameDecorOfAttachedViews();
- protected native void resizeEvent(QResizeEvent arg1);
+ protected native void resizeEvent(TQResizeEvent arg1);
/**
Creates a new MDI taskbar (showing the MDI views as taskbar entries) and shows it.
@short Creates a new MDI taskbar (showing the MDI views as taskbar entries) and shows it.
@@ -631,8 +631,8 @@ public class KMdiMainFrm extends DockMainWindow {
@short prevents fillWindowMenu() from m_pWindowMenu.clear().
*/
protected native void blockClearingOfWindowMenu(boolean bBlocked);
- // void findToolViewsDockedToMain(QPtrList<KDockWidget>* arg1,KDockWidget::DockPosition arg2); >>>> NOT CONVERTED
- // void dockToolViewsIntoContainers(QPtrList<KDockWidget>& arg1,KDockWidget* arg2); >>>> NOT CONVERTED
+ // void findToolViewsDockedToMain(TQPtrList<KDockWidget>* arg1,KDockWidget::DockPosition arg2); >>>> NOT CONVERTED
+ // void dockToolViewsIntoContainers(TQPtrList<KDockWidget>& arg1,KDockWidget* arg2); >>>> NOT CONVERTED
protected native ArrayList prepareIdealToTabs(KDockWidget container);
protected native void idealToolViewsToStandardTabs(String[] widgetNames, int pos, int sizee);
/** Get tabwidget visibility @short Get tabwidget visibility
@@ -679,7 +679,7 @@ public class KMdiMainFrm extends DockMainWindow {
Popups the "Window" menu. See also windowPopup() .
@short Popups the "Window" menu.
*/
- protected native void popupWindowMenu(QPoint p);
+ protected native void popupWindowMenu(TQPoint p);
/**
The timer for main widget moving has elapsed . send drag end to all concerned views.
@short The timer for main widget moving has elapsed . send drag end to all concerned views.